@@ -1,11 +1,12 @@
-package TestAppWx::textctrl;
+package # Hide from pause
+   TestAppWx::textctrl;
 
 use strict;
 use warnings;
 
 use Test::More;
 use Wx ':everything';
-use Catalyst::Engine::Wx::Event qw(EVT_BUTTON EVT_CLOSE EVT);
+use Catalyst::Engine::Wx::Event qw(CAT_EVT_BUTTON CAT_EVT_CLOSE CAT_EVT);
 
 use base 'Wx::TextCtrl';
 
@@ -16,7 +17,7 @@ sub new {
 
    ok (ref($self) eq 'TestAppWx::textctrl', 'TestAppWx::textctrl');
    
-   EVT( $c->stash->{_parent}, '/event_with_params', { scalar => 'data', array => ['test', 'of', 'array'] } );
+   CAT_EVT( $c->stash->{_parent}, '/event_with_params', { scalar => 'data', array => ['test', 'of', 'array'] } );
    
    return 1;
 }
